package net.wanji.databus.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.springframework.data.elasticsearch.annotations.Field;
import org.springframework.data.elasticsearch.annotations.FieldType;

import java.util.List;

/**
 * @author duanruiming
 * @date 2023/11/27 9:37
 */
@EqualsAndHashCode(callSuper = true)
@Data
@ApiModel(value = "LightsStatusVO2", description = "实时灯态信息实体版本2")
public class LightsStatusVO2 extends BaseCrossInfo {
    @ApiModelProperty(value = "运行模式 `2=手动锁定当前相位`，`3=手动全红`，`4=手动黄闪`，`5=手动关灯`，" +
            "`6=全红闪控制`，`7=全黄控制`，`8=正常按计划运行`，`9=手动步进控制`，`10=自动步进控制`，`11=恢复时间表`，`255=临时控制方案`")
    private String runMode;
    @ApiModelProperty(value = "控制模式")
    private String controlMode;
    @ApiModelProperty(value = "方案开始时间", notes = "目前没有用到")
    private String schemeStartTime;
    @ApiModelProperty(value = "相位周期剩余时长")
    private Integer cycleCountDown;
    @ApiModelProperty(value = "相位周期剩余时长")
    private Integer cyclePhaseCountDown;
    @ApiModelProperty(value = "相位周期时长")
    private Integer cycleLen;

    @ApiModelProperty(value = "当前相位号")
    private String phaseId;
    @ApiModelProperty(value = "当前方案号")
    private String schemeId;
    @ApiModelProperty(value = "灯组状态")
    private List<DirInfo> dirLampGroupMapList;
    @ApiModelProperty(value = "数据上报时间戳")
    @Field(type = FieldType.Keyword, name = "timeStamp")
    private String timeStamp;

    @Data
    @ApiModel(value = "DirInfo", description = "灯组方向转向信息")
    public static class DirInfo {
        @ApiModelProperty(value = "方向")
        private String dir;
        @ApiModelProperty(value = "转向信息")
        List<TurnInfo> turnList;
    }

    @Data
    @ApiModel(value = "TurnInfo", description = "灯组转向灯态红灯倒计时")
    public static class TurnInfo {
        @ApiModelProperty(value = "转向")
        private String turn;
        @ApiModelProperty(value = "灯色")
        private String color;
        @ApiModelProperty(value = "红灯倒计时")
        private Integer countDown;
    }

}
